close all
%% Multipole graph
opts = delimitedTextImportOptions("NumVariables", 3);

% Specify range and delimiter
opts.DataLines = [9, Inf];
opts.Delimiter = " ";

% Specify column names and types
opts.VariableNames = ["VarName1", "Model", "Var3"];
opts.SelectedVariableNames = ["VarName1", "Model"];
opts.VariableTypes = ["double", "double", "string"];

% Specify file level properties
opts.ExtraColumnsRule = "ignore";
opts.EmptyLineRule = "read";
opts.ConsecutiveDelimitersRule = "join";
opts.LeadingDelimitersRule = "ignore";

% Specify variable properties
opts = setvaropts(opts, "Var3", "WhitespaceRule", "preserve");
opts = setvaropts(opts, "Var3", "EmptyFieldRule", "auto");

% Import the data
SiliconMultipoleGraph = readtable("U:\LASO\AnisotropicScattering\Thesis\Chapter3\MultipoleDecompDielectricNanoparticle\SiliconMultipoleGraph.txt", opts);

SiliconMultipoleGraph = table2array(SiliconMultipoleGraph);

SiliconMultipoleGraph = reshape(SiliconMultipoleGraph,281,12);

clear opts

figure%('Position',[0, 0, 1800, 900])
hold on
for i=1:4
    plot(SiliconMultipoleGraph(:,1),SiliconMultipoleGraph(:,i+6))
end
plot(SiliconMultipoleGraph(:,1),SiliconMultipoleGraph(:,11),'Color',[239 96 163]/255)
plot(SiliconMultipoleGraph(:,1),SiliconMultipoleGraph(:,12),'k')
xlabel('wavelength [nm]')
ylabel('Normalized scatter cross section [-]')
legend('Magnetic Dipole','Electric Dipole','Magnetic Quadrupole','Electric Quadrupole','Multipole Sum','Extinction Cross Section')
set(gcf,'Position',[100 100 1000 540])
axis([350 750 0 10])

%% Near Field
opts = delimitedTextImportOptions("NumVariables", 4);

% Specify range and delimiter
opts.DataLines = [9, Inf];
opts.Delimiter = " ";

% Specify column names and types
opts.VariableNames = ["VarName1", "Model", "SiliconMultipoleSphere_solvedmph", "VarName4"];
opts.VariableTypes = ["double", "double", "double", "double"];

% Specify file level properties
opts.ExtraColumnsRule = "ignore";
opts.EmptyLineRule = "read";
opts.ConsecutiveDelimitersRule = "join";
opts.LeadingDelimitersRule = "ignore";

% Import the data
SiliconMultipoleNearField = readtable("U:\LASO\AnisotropicScattering\Thesis\Chapter3\MultipoleDecompDielectricNanoparticle\SiliconMultipoleNearField.txt", opts);

SiliconMultipoleNearField = table2array(SiliconMultipoleNearField);

clear opts

F = scatteredInterpolant(SiliconMultipoleNearField(:,1)*1e9,SiliconMultipoleNearField(:,2)*1e9,SiliconMultipoleNearField(:,4));

[xq,yq] = meshgrid(linspace(-200,200,1001),linspace(-200,200,1001));

zq = F(xq,yq);

figure
pcolor(xq,yq,zq)
shading flat
grid on
colormap turbo
axis square
a = colorbar;
xlabel('x [nm]')
ylabel('z [nm]')
ylabel(a,'Absolute electric field [V/m]','FontSize',16)
set(gcf,'Position',[100 100 550 450])
title('Near field')

%% Far field

opts = delimitedTextImportOptions("NumVariables", 4);

% Specify range and delimiter
opts.DataLines = [9, Inf];
opts.Delimiter = " ";

% Specify column names and types
opts.VariableNames = ["VarName1", "Model", "Var3", "Var4"];
opts.SelectedVariableNames = ["VarName1", "Model"];
opts.VariableTypes = ["double", "double", "string", "string"];

% Specify file level properties
opts.ExtraColumnsRule = "ignore";
opts.EmptyLineRule = "read";
opts.ConsecutiveDelimitersRule = "join";
opts.LeadingDelimitersRule = "ignore";

% Specify variable properties
opts = setvaropts(opts, ["Var3", "Var4"], "WhitespaceRule", "preserve");
opts = setvaropts(opts, ["Var3", "Var4"], "EmptyFieldRule", "auto");

% Import the data
SiliconMultipoleFarField = readtable("U:\LASO\AnisotropicScattering\Thesis\Chapter3\MultipoleDecompDielectricNanoparticle\SiliconMultipoleFarField.txt", opts);

SiliconMultipoleFarField = table2array(SiliconMultipoleFarField);

clear opts

SiliconMultipoleFarField = reshape(SiliconMultipoleFarField,102,4);

figure
polarplot(SiliconMultipoleFarField(:,1),SiliconMultipoleFarField(:,3))
hold on
polarplot(SiliconMultipoleFarField(:,1),SiliconMultipoleFarField(:,4))
rticklabels({})
legend('xz-plane','xy-plane')
set(gcf,'Position',[100 100 550 450])
title('Far field')
thetaticklabels({'0°','30°','60°','90°','120°','150°','180°','210°','240°','270°','300°','330°'})
