close all
%% Multipole graph
opts = delimitedTextImportOptions("NumVariables", 3);

% Specify range and delimiter
opts.DataLines = [9, Inf];
opts.Delimiter = " ";

% Specify column names and types
opts.VariableNames = ["VarName1", "Model", "Var3"];
opts.SelectedVariableNames = ["VarName1", "Model"];
opts.VariableTypes = ["double", "double", "string"];

% Specify file level properties
opts.ExtraColumnsRule = "ignore";
opts.EmptyLineRule = "read";
opts.ConsecutiveDelimitersRule = "join";
opts.LeadingDelimitersRule = "ignore";

% Specify variable properties
opts = setvaropts(opts, "Var3", "WhitespaceRule", "preserve");
opts = setvaropts(opts, "Var3", "EmptyFieldRule", "auto");

% Import the data
TitaniaMultipoleGraph = readtable("U:\LASO\AnisotropicScattering\Thesis\Chapter3\MultipoleDecompTitaniaNanoparticle\TitaniaMultipoleGraph.txt", opts);

TitaniaMultipoleGraph = table2array(TitaniaMultipoleGraph);

TitaniaMultipoleGraph = reshape(TitaniaMultipoleGraph,251,16);

clear opts

figure%('Position',[0, 0, 1800, 900])
hold on
for i=1:5
    plot(TitaniaMultipoleGraph(:,1),TitaniaMultipoleGraph(:,i+8))
end
plot(TitaniaMultipoleGraph(:,1),TitaniaMultipoleGraph(:,15),'Color',[239 96 163]/255)
plot(TitaniaMultipoleGraph(:,1),TitaniaMultipoleGraph(:,16),'k')
xlabel('wavelength [nm]')
ylabel('Normalized scatter cross section [-]')
legend('Magnetic Dipole','Electric Dipole','Magnetic Quadrupole','Electric Quadrupole','Magnetic Octupole','Multipole Sum','Extinction Cross Section')
set(gcf,'Position',[100 100 1000 540])
axis([350 750 0 10])

%% Near Field
opts = delimitedTextImportOptions("NumVariables", 4);

% Specify range and delimiter
opts.DataLines = [9, Inf];
opts.Delimiter = " ";

% Specify column names and types
opts.VariableNames = ["VarName1", "Model", "TitaniaMultipoleSphere_solvedmph", "VarName4"];
opts.VariableTypes = ["double", "double", "double", "double"];

% Specify file level properties
opts.ExtraColumnsRule = "ignore";
opts.EmptyLineRule = "read";
opts.ConsecutiveDelimitersRule = "join";
opts.LeadingDelimitersRule = "ignore";

% Import the data
TitaniaMultipoleNearField = readtable("U:\LASO\AnisotropicScattering\Thesis\Chapter3\MultipoleDecompTitaniaNanoparticle\TitaniaMultipoleNearField.txt", opts);

TitaniaMultipoleNearField = table2array(TitaniaMultipoleNearField);

clear opts

F = scatteredInterpolant(TitaniaMultipoleNearField(:,1)*1e9,TitaniaMultipoleNearField(:,2)*1e9,TitaniaMultipoleNearField(:,4));

[xq,yq] = meshgrid(linspace(-400,400,1001),linspace(-400,400,1001));

zq = F(xq,yq);

figure
pcolor(xq,yq,zq)
shading flat
grid on
colormap turbo
axis square
a = colorbar;
xlabel('x [nm]')
ylabel('z [nm]')
ylabel(a,'Absolute electric field [V/m]','FontSize',16)
set(gcf,'Position',[100 100 550 450])
title('Near field')

%% Far field

opts = delimitedTextImportOptions("NumVariables", 4);

% Specify range and delimiter
opts.DataLines = [9, Inf];
opts.Delimiter = " ";

% Specify column names and types
opts.VariableNames = ["VarName1", "Model", "Var3", "Var4"];
opts.SelectedVariableNames = ["VarName1", "Model"];
opts.VariableTypes = ["double", "double", "string", "string"];

% Specify file level properties
opts.ExtraColumnsRule = "ignore";
opts.EmptyLineRule = "read";
opts.ConsecutiveDelimitersRule = "join";
opts.LeadingDelimitersRule = "ignore";

% Specify variable properties
opts = setvaropts(opts, ["Var3", "Var4"], "WhitespaceRule", "preserve");
opts = setvaropts(opts, ["Var3", "Var4"], "EmptyFieldRule", "auto");

% Import the data
TitaniaMultipoleFarField = readtable("U:\LASO\AnisotropicScattering\Thesis\Chapter3\MultipoleDecompTitaniaNanoparticle\TitaniaMultipoleFarField.txt", opts);

TitaniaMultipoleFarField = table2array(TitaniaMultipoleFarField);

clear opts

TitaniaMultipoleFarField = reshape(TitaniaMultipoleFarField,101,4);

figure
polarplot(TitaniaMultipoleFarField(:,1),TitaniaMultipoleFarField(:,3))
hold on
polarplot(TitaniaMultipoleFarField(:,1),TitaniaMultipoleFarField(:,4))
rticklabels({})
legend('xz-plane','xy-plane')
set(gcf,'Position',[100 100 550 450])
title('Far field')
thetaticklabels({'0°','30°','60°','90°','120°','150°','180°','210°','240°','270°','300°','330°'})

% load TitaniumDioxideMultipoleSphere.mat
% 
% figure
% hold on
% for i=1:5
%     plot(TitaniumDioxideMultipoleSphere(:,1),TitaniumDioxideMultipoleSphere(:,i+8))
% end
% plot(TitaniumDioxideMultipoleSphere(:,1),TitaniumDioxideMultipoleSphere(:,15),'Color',[239 96 163]/255)
% plot(TitaniumDioxideMultipoleSphere(:,1),TitaniumDioxideMultipoleSphere(:,16),'k')
% xlabel('wavelength [nm]')
% ylabel('Normalized scatter cross section [-]')
% legend('Magnetic Dipole','Electric Dipole','Magnetic Quadrupole','Electric Quadrupole','Magnetic Octupole','Multipole Sum','Extinction Cross Section')
% set(gcf,'Position',[100 100 1000 540])
% axis([350 750 0 10])